@@ -448,6 +448,15 @@ test_cs!(vmove_to_with_width, &[
     rect(0, 20, 0, 20)
 );
 
+// Use only the first width.
+test_cs!(two_vmove_to_with_width, &[
+    CFFInt(10), CFFInt(20), UInt8(operator::VERTICAL_MOVE_TO),
+    CFFInt(10), CFFInt(20), UInt8(operator::VERTICAL_MOVE_TO),
+    UInt8(operator::ENDCHAR),
+], "M 0 20 Z M 0 40 Z ",
+    rect(0, 20, 0, 40)
+);
+
 test_cs!(line_to, &[
     CFFInt(10), CFFInt(20), UInt8(operator::MOVE_TO),
     CFFInt(30), CFFInt(40), UInt8(operator::LINE_TO),
@@ -637,19 +646,12 @@ test_cs_err!(line_to_without_move_to, &[
     UInt8(operator::ENDCHAR),
 ], CFFError::MissingMoveTo);
 
-// Width must be set only once.
-test_cs_err!(two_vmove_to_with_width, &[
-    CFFInt(10), CFFInt(20), UInt8(operator::VERTICAL_MOVE_TO),
-    CFFInt(10), CFFInt(20), UInt8(operator::VERTICAL_MOVE_TO),
-    UInt8(operator::ENDCHAR),
-], CFFError::InvalidArgumentsStackLength);
-
 test_cs_err!(move_to_with_too_many_coords, &[
     CFFInt(10), CFFInt(10), CFFInt(10), CFFInt(20), UInt8(operator::MOVE_TO),
     UInt8(operator::ENDCHAR),
 ], CFFError::InvalidArgumentsStackLength);
 
-test_cs_err!(move_to_with_not_enought_coords, &[
+test_cs_err!(move_to_with_not_enough_coords, &[
     CFFInt(10), UInt8(operator::MOVE_TO),
     UInt8(operator::ENDCHAR),
 ], CFFError::InvalidArgumentsStackLength);
@@ -659,7 +661,7 @@ test_cs_err!(hmove_to_with_too_many_coords, &[
     UInt8(operator::ENDCHAR),
 ], CFFError::InvalidArgumentsStackLength);
 
-test_cs_err!(hmove_to_with_not_enought_coords, &[
+test_cs_err!(hmove_to_with_not_enough_coords, &[
     UInt8(operator::HORIZONTAL_MOVE_TO),
     UInt8(operator::ENDCHAR),
 ], CFFError::InvalidArgumentsStackLength);
@@ -669,7 +671,7 @@ test_cs_err!(vmove_to_with_too_many_coords, &[
     UInt8(operator::ENDCHAR),
 ], CFFError::InvalidArgumentsStackLength);
 
-test_cs_err!(vmove_to_with_not_enought_coords, &[
+test_cs_err!(vmove_to_with_not_enough_coords, &[
     UInt8(operator::VERTICAL_MOVE_TO),
     UInt8(operator::ENDCHAR),
 ], CFFError::InvalidArgumentsStackLength);
@@ -711,7 +713,7 @@ test_cs_err!(curve_to_with_invalid_num_of_coords_2, &[
     UInt8(operator::ENDCHAR),
 ], CFFError::InvalidArgumentsStackLength);
 
-test_cs_err!(hh_curve_to_with_not_enought_coords, &[
+test_cs_err!(hh_curve_to_with_not_enough_coords, &[
     CFFInt(10), CFFInt(20), UInt8(operator::MOVE_TO),
     CFFInt(30), CFFInt(40), CFFInt(50), UInt8(operator::HH_CURVE_TO),
     UInt8(operator::ENDCHAR),
@@ -724,7 +726,7 @@ test_cs_err!(hh_curve_to_with_too_many_coords, &[
     UInt8(operator::ENDCHAR),
 ], CFFError::InvalidArgumentsStackLength);
 
-test_cs_err!(vv_curve_to_with_not_enought_coords, &[
+test_cs_err!(vv_curve_to_with_not_enough_coords, &[
     CFFInt(10), CFFInt(20), UInt8(operator::MOVE_TO),
     CFFInt(30), CFFInt(40), CFFInt(50), UInt8(operator::VV_CURVE_TO),
     UInt8(operator::ENDCHAR),
